﻿
/*---------------------------------------------------------------------------

    Filename: hello_world_wide_web_form.js

    (C) Copyright 2008, Kirix Corporation, All Rights Reserved.

    License:  MIT license (http://www.kirix.com/legal/mit_license)

    Summary:  Opens a form that shows search results for the phrase
              "Hello World" on Google, Yahoo, and Wikipedia.

    Developer(s):   David Z. Williams

---------------------------------------------------------------------------*/


class HelloWorldWideWebForm extends Form
{
    // class: HelloWorldWideWebForm
    //
    // summary: top-level form

    function HelloWorldWideWebForm()
    {
        // function: HelloWorldWideWebForm()
        //
        // summary: constructor function that defines the form
        
        // call the constructor on the base Form object     
        super("Hello World Wide Web", 100, 100, 800, 600);
        setMinSize(480,360);
        
        // create language choice box
        m_language_choicebox = new ChoiceBox;
        m_language_choicebox.add("English");
        m_language_choicebox.add("Español");
        m_language_choicebox.add("Deutsch");
        m_language_choicebox.add("Français");
        m_language_choicebox.select(0);
        m_language_choicebox.selectionChanged.connect(this, onLanguageChanged);
        
        // create buttons
        m_google_button = new Button("Google");
        m_google_button.click.connect(this, onGoogleClicked);
        
        m_yahoo_button = new Button("Yahoo!");
        m_yahoo_button.click.connect(this, onYahooClicked);

        m_wikipedia_button = new Button("Wikipedia");
        m_wikipedia_button.click.connect(this, onWikipediaClicked);
        
        // create browser control
        m_browser = new WebBrowser;
        
        // create navigation layout
        var nav_layout = new BoxLayout(Layout.Horizontal);
        nav_layout.add(new Label("Language:"), 0, Layout.Center);
        nav_layout.addSpacer(5);
        nav_layout.add(m_language_choicebox, 0, Layout.Center);
        nav_layout.addSpacer(8);
        nav_layout.add(m_google_button, 0, Layout.Center);
        nav_layout.addSpacer(8);
        nav_layout.add(m_yahoo_button, 0, Layout.Center);
        nav_layout.addSpacer(8);
        nav_layout.add(m_wikipedia_button, 0, Layout.Center);
        
        // create main layout
        var main_layout = new BoxLayout(Layout.Vertical);
        main_layout.addSpacer(8);
        main_layout.add(nav_layout, 0, Layout.Left | Layout.Right | Layout.Expand, 8);
        main_layout.addSpacer(8);
        main_layout.add(m_browser, 1, Layout.Expand);
        setLayout(main_layout);

        // start with the Google results for "Hello World" in English
        onGoogleClicked();
    }
    
    function onLanguageChanged()
    {
        // function: onLanguageChanged()
        //
        // summary: updates the current site when the language changes
    
        if (m_mode == "google")
            onGoogleClicked();
             else if (m_mode == "yahoo")
            onYahooClicked();
             else if (m_mode == "wikipedia")
            onWikipediaClicked();
    }
    
    function onGoogleClicked()
    {
        // function: onGoogleClicked()
        //
        // summary: when the Google button is clicked, constructs a
        // URL and loads the appropriate web content

        var url;
        var sel = m_language_choicebox.getSelection();

        if (sel == 0)
            url = "http://www.google.com/search?hl=en&q=Hello+World&btnG=Google+Search";
             else if (sel == 1)
            url = "http://www.google.es/search?hl=es&q=Hola+Mundo&btnG=Buscar+con+Google&meta=";
             else if (sel == 2)
            url = "http://www.google.de/search?hl=de&q=Hallo+Welt&btnG=Google-Suche&meta=";
             else if (sel == 3)
            url = "http://www.google.fr/search?hl=fr&q=Bonjour+le+monde&btnG=Recherche+Google&meta=";
        
        m_browser.navigate(url);
        m_mode = "google";
    }

    function onYahooClicked()
    {
        // function: onYahooClicked()
        //
        // summary: when the Yahoo! button is clicked, constructs a
        // URL and loads the appropriate web content

        var url;
        var sel = m_language_choicebox.getSelection();

        if (sel == 0)
            url = "http://search.yahoo.com/search?p=Hello+World&fr=yfp-t-501&toggle=1&cop=mss&ei=UTF-8";
             else if (sel == 1)
            url = "http://es.search.yahoo.com/search?p=Hola+Mundo&fr=yfp-t-501&ei=UTF-8&meta=vl%3D";
             else if (sel == 2)
            url = "http://de.search.yahoo.com/search?p=Hallo+Welt&fr=yfp-t-501&ei=UTF-8&rd=r1";
             else if (sel == 3)
            url = "http://fr.search.yahoo.com/search?p=Bonjour+le+monde&fr=yfp-t-501&ei=UTF-8&rd=r1";
        
        m_browser.navigate(url);
        m_mode = "yahoo";
    }

    function onWikipediaClicked()
    {
        // function: onWikipediaClicked()
        //
        // summary: when the Wikipedia button is clicked, constructs a
        // URL and loads the appropriate web content

        var url;
        var sel = m_language_choicebox.getSelection();

        if (sel == 0)
            url = "http://en.wikipedia.org/wiki/Hello_World";
             else if (sel == 1)
            url = "http://es.wikipedia.org/wiki/Hola_Mundo";
             else if (sel == 2)
            url = "http://de.wikipedia.org/wiki/Hallo_Welt";
             else if (sel == 3)
            url = "http://fr.wikipedia.org/wiki/Hello_World";
        
        m_browser.navigate(url);
        m_mode = "wikipedia";
    }

    // member variables
    var m_language_choicebox;
    var m_google_button;
    var m_yahoo_button;
    var m_wikipedia_button;
    var m_browser;    
    var m_mode;    
}

